@@ -3,14 +3,13 @@ package Baseobject;
 use strict ;
 use Cwd;
 use Carp qw (cluck carp);
-
+our @CARP_NOT;
 use Data::Dumper;
-
 require      Exporter;
 our @ISA = qw (Exporter);
 our @EXPORT = qw (baseconfigure verbosity freezeverbosity dumper);
 
-our $VERSION = "1.23";
+our $VERSION = "1.24";
 
 $Baseobject::directfeedback=0; # for downward compatibility
 $Baseobject::quickdeath=0;
@@ -224,7 +223,7 @@ sub checkneeds {
 
 sub dumper {
 	my $string = Dumper(@_);
-	my ($package, $file, $line) = caller(1);
+	my ($package, $file, $line) = caller();
 	$string .= " Inspect called at: $file line $line\n";
 }
 
@@ -331,14 +330,25 @@ sub verbosity {
 		: $Baseobject::verbosity;
 }
 
+# 
 sub verbose {
 	my $self = shift;
-	carp @_ if verbosity;
+	my ($package, $file, $line) = caller;
+	my $string = join('', @_);
+	chomp($string);
+	print STDERR "$string at $file line $line (debug)" if verbosity >= 1;
+
 }
 
 sub debug {
 	my $self = shift;
-	carp @_ if verbosity >= 2;
+	my ($package, $file, $line) = caller;
+	my $string = join('', @_);
+	chomp($string);
+	print STDERR "$string at $file line $line (debug)" if verbosity >= 2;
+
+	# carp heeft een off by one error in callstack als debug vanuit een eval() wordt aangeroepen:
+	# carp @_ if verbosity >= 2;
 }
 
 sub expandvars {
